do.fit estimates the background for individual banks according to the Bayesian approach using the Differential Evolution algorithm
do.fit.banks(data, bounds.lower, bounds.upper, knots.n.left,
knots.n.right, x.boundary, analytical=FALSE, control,
save.to="")an object of type data. See set.data for details.
numerics, lower and upper bounds for the fitted spline values.
numerics that specify the number of knots. knots.n.left and knots.n.right knots are created on the left and on the right of x.boundary point, respectively.
logical. If TRUE background is approximated by an analytical function \(f(x)=P_1\exp(-P_2x)x^{P_3} + P_4/[(x-P_5)^2+P_6^2]\).
list, the return value of set.control. Specifies various parameters of the Differential Evolution optimization algorithm implemented in DEoptim.
character, a filename for saving the results.
A list of elements. Each element contains a return value of do.fit for the corresponding data bank.
This function simplifies the procedure for estimating the background for several detector banks by a multiple call of do.fit. Other relevant parameters are set to: stdev=FALSE, scale=NA, p.bkg=.5.
For neutron scattering, the incoherent background exhibits a broad peak at low Q and decays gradually at higher Q. Hence, we suggest to use different numbers of knots for the low- and high-Q regions. See BBEST-package for details.